# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmLLMDocumentEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact': 'OrmArtifact',
        'llm_document_llm_knowledge_job': 'list[OrmLLMDocumentLLMKnowledgeJob]',
        'llm_knowledge': 'OrmLLMKnowledge',
        'organization': 'OrmOrganization',
        'uploaded_by': 'OrmUser'
    }

    attribute_map = {
        'artifact': 'artifact',
        'llm_document_llm_knowledge_job': 'llm_document_llm_knowledge_job',
        'llm_knowledge': 'llm_knowledge',
        'organization': 'organization',
        'uploaded_by': 'uploaded_by'
    }

    def __init__(self, artifact=None, llm_document_llm_knowledge_job=None, llm_knowledge=None, organization=None, uploaded_by=None, local_vars_configuration=None):  # noqa: E501
        """OrmLLMDocumentEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact = None
        self._llm_document_llm_knowledge_job = None
        self._llm_knowledge = None
        self._organization = None
        self._uploaded_by = None
        self.discriminator = None

        if artifact is not None:
            self.artifact = artifact
        if llm_document_llm_knowledge_job is not None:
            self.llm_document_llm_knowledge_job = llm_document_llm_knowledge_job
        if llm_knowledge is not None:
            self.llm_knowledge = llm_knowledge
        if organization is not None:
            self.organization = organization
        if uploaded_by is not None:
            self.uploaded_by = uploaded_by

    @property
    def artifact(self):
        """Gets the artifact of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The artifact of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmArtifact
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this OrmLLMDocumentEdges.


        :param artifact: The artifact of this OrmLLMDocumentEdges.  # noqa: E501
        :type artifact: OrmArtifact
        """

        self._artifact = artifact

    @property
    def llm_document_llm_knowledge_job(self):
        """Gets the llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: list[OrmLLMDocumentLLMKnowledgeJob]
        """
        return self._llm_document_llm_knowledge_job

    @llm_document_llm_knowledge_job.setter
    def llm_document_llm_knowledge_job(self, llm_document_llm_knowledge_job):
        """Sets the llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.


        :param llm_document_llm_knowledge_job: The llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501
        :type llm_document_llm_knowledge_job: list[OrmLLMDocumentLLMKnowledgeJob]
        """

        self._llm_document_llm_knowledge_job = llm_document_llm_knowledge_job

    @property
    def llm_knowledge(self):
        """Gets the llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmLLMKnowledge
        """
        return self._llm_knowledge

    @llm_knowledge.setter
    def llm_knowledge(self, llm_knowledge):
        """Sets the llm_knowledge of this OrmLLMDocumentEdges.


        :param llm_knowledge: The llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501
        :type llm_knowledge: OrmLLMKnowledge
        """

        self._llm_knowledge = llm_knowledge

    @property
    def organization(self):
        """Gets the organization of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The organization of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmLLMDocumentEdges.


        :param organization: The organization of this OrmLLMDocumentEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def uploaded_by(self):
        """Gets the uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._uploaded_by

    @uploaded_by.setter
    def uploaded_by(self, uploaded_by):
        """Sets the uploaded_by of this OrmLLMDocumentEdges.


        :param uploaded_by: The uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501
        :type uploaded_by: OrmUser
        """

        self._uploaded_by = uploaded_by

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmLLMDocumentEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmLLMDocumentEdges):
            return True

        return self.to_dict() != other.to_dict()
